.node {
    background: var(--color-bg-secondary);
    border: 1px solid var(--color-border);
    border-radius: var(--radius-md);
    padding: var(--space-3) var(--space-4);
    font-family: var(--font-mono);
    min-width: 180px;
    max-width: 360px;
    overflow: hidden;
}

.nodeLabel {
    font-size: var(--font-size-xl);
    color: var(--color-text-primary);
    font-weight: 600;
}

.nodeSubtext {
    font-size: var(--font-size-lg);
    color: var(--color-text-secondary);
    margin-top: var(--space-1);
    word-break: break-all;
    overflow-wrap: anywhere;
}

.nodeDetail {
    font-size: var(--font-size-lg);
    color: var(--color-text-muted);
    margin-top: var(--space-1);
}

.nodeDetailList {
    font-size: var(--font-size-base);
    color: var(--color-text-muted);
    margin-top: var(--space-1);
    line-height: 1.5;
    max-height: 120px;
    overflow-y: auto;
}

.nodeTag {
    display: inline-block;
    font-size: var(--font-size-sm);
    padding: 2px var(--space-2);
    border-radius: 3px;
    background: var(--color-bg-tertiary);
    color: var(--color-text-secondary);
    margin-right: 3px;
    margin-bottom: 3px;
}

.nodeParamRow {
    display: flex;
    justify-content: space-between;
    font-size: var(--font-size-sm);
    color: var(--color-text-muted);
    padding: 2px 0;
}

.nodeParamKey {
    color: var(--color-text-secondary);
}

.nodeParamValue {
    color: var(--color-text-primary);
    margin-left: var(--space-2);
}

.nodeDivider {
    border: none;
    border-top: 1px solid var(--color-border-subtle);
    margin: var(--space-1) 0;
}

.sourceNode {
    border-color: var(--color-node-source);
}

.modelNode {
    border-color: var(--color-node-model);
}

.featuresNode {
    border-color: var(--color-node-features);
}

.ensembleNode {
    border-color: var(--color-node-ensemble);
}

.calibrationNode {
    border-color: var(--color-node-calibration);
}

.outputNode {
    border-color: var(--color-node-output);
}

.viewNode {
    border-color: var(--color-accent);
}

.handle {
    width: 8px;
    height: 8px;
    background: var(--color-border);
}

.node:hover {
    box-shadow: var(--shadow-lg);
    border-color: var(--color-accent);
    transition: box-shadow 200ms ease, border-color 200ms ease;
}

.node {
    transition: box-shadow 200ms ease, border-color 200ms ease;
}

@keyframes nodePulse {
    0% { box-shadow: 0 0 4px var(--color-status-running); }
    50% { box-shadow: 0 0 16px var(--color-status-running), 0 0 24px var(--color-status-running); }
    100% { box-shadow: 0 0 4px var(--color-status-running); }
}

.nodeRunning {
    animation: nodePulse 1.5s ease-in-out infinite;
}

.nodeSelected,
.nodeSelected:hover {
    border-color: var(--color-accent);
    box-shadow: 0 0 0 2px var(--color-accent), 0 4px 12px var(--color-accent-a30);
    transition: none;
}

.runningIndicator {
    display: inline-block;
    font-size: var(--font-size-xs);
    padding: 1px var(--space-2);
    border-radius: 3px;
    background: var(--color-status-running);
    color: var(--color-bg-primary);
    margin-left: var(--space-1);
    font-weight: 700;
    text-transform: uppercase;
    letter-spacing: 0.03em;
}

.experimentNode {
    border-color: var(--color-tool-experiments);
    border-width: 2px;
    border-style: dashed;
}

.experimentBadge {
    display: inline-block;
    font-size: var(--font-size-xs);
    padding: 1px var(--space-2);
    border-radius: 3px;
    background: var(--color-orange-a15);
    color: var(--color-tool-experiments);
    margin-left: var(--space-1);
    font-weight: 700;
    text-transform: uppercase;
    letter-spacing: 0.03em;
}
