[data-theme="solarized-dark"] {
    --color-bg-primary: #002b36;
    --color-bg-secondary: #073642;
    --color-bg-tertiary: #0a3f4c;
    --color-bg-hover: #0d4a58;
    --color-border: #1a5566;
    --color-border-subtle: #0a3f4c;

    --color-text-primary: #fdf6e3;
    --color-text-secondary: #93a1a1;
    --color-text-muted: #657b83;

    --color-accent: #268bd2;
    --color-success: #859900;
    --color-warning: #b58900;
    --color-error: #dc322f;
    --color-orange: #cb4b16;

    --color-accent-a06: rgba(38, 139, 210, 0.06);
    --color-accent-a08: rgba(38, 139, 210, 0.08);
    --color-accent-a10: rgba(38, 139, 210, 0.1);
    --color-accent-a12: rgba(38, 139, 210, 0.12);
    --color-accent-a25: rgba(38, 139, 210, 0.25);
    --color-accent-a30: rgba(38, 139, 210, 0.3);

    --color-success-a15: rgba(133, 153, 0, 0.15);
    --color-success-a30: rgba(133, 153, 0, 0.3);
    --color-warning-a15: rgba(181, 137, 0, 0.15);
    --color-warning-a40: rgba(181, 137, 0, 0.4);
    --color-error-a40: rgba(220, 50, 47, 0.4);
    --color-orange-a15: rgba(203, 75, 22, 0.15);
    --color-orange-a30: rgba(203, 75, 22, 0.3);
    --color-muted-a15: rgba(101, 123, 131, 0.15);

    --color-status-pending: #657b83;
    --color-status-running: #268bd2;
    --color-status-complete: #859900;
    --color-status-error: #dc322f;

    --color-node-source: #6c71c4;
    --color-node-features: #2aa198;
    --color-node-model: #268bd2;
    --color-node-ensemble: #859900;
    --color-node-calibration: #b58900;
    --color-node-output: #cb4b16;

    --color-tool-models: #268bd2;
    --color-tool-pipeline: #859900;
    --color-tool-data: #6c71c4;
    --color-tool-features: #2aa198;
    --color-tool-experiments: #cb4b16;
    --color-tool-config: #b58900;

    --shadow-sm: 0 1px 2px rgba(0, 0, 0, 0.4);
    --shadow-md: 0 4px 12px rgba(0, 0, 0, 0.35);
    --shadow-lg: 0 4px 12px rgba(0, 0, 0, 0.45);
    --shadow-glow-accent: 0 0 12px var(--color-accent-a25), inset 0 0 0 1px var(--color-accent-a10);
}
