[data-theme="rosepine"] {
    /* Rosé Pine — muted rose/gold on dark navy */
    --color-bg-primary: #191724;
    --color-bg-secondary: #1f1d2e;
    --color-bg-tertiary: #26233a;
    --color-bg-hover: #2a2740;
    --color-border: #393552;
    --color-border-subtle: #26233a;

    --color-text-primary: #e0def4;
    --color-text-secondary: #908caa;
    --color-text-muted: #6e6a86;

    --color-accent: #ebbcba;
    --color-success: #9ccfd8;
    --color-warning: #f6c177;
    --color-error: #eb6f92;
    --color-orange: #f6c177;

    --color-accent-a06: rgba(235, 188, 186, 0.06);
    --color-accent-a08: rgba(235, 188, 186, 0.08);
    --color-accent-a10: rgba(235, 188, 186, 0.1);
    --color-accent-a12: rgba(235, 188, 186, 0.12);
    --color-accent-a25: rgba(235, 188, 186, 0.25);
    --color-accent-a30: rgba(235, 188, 186, 0.3);

    --color-success-a15: rgba(156, 207, 216, 0.15);
    --color-success-a30: rgba(156, 207, 216, 0.3);
    --color-warning-a15: rgba(246, 193, 119, 0.15);
    --color-warning-a40: rgba(246, 193, 119, 0.4);
    --color-error-a40: rgba(235, 111, 146, 0.4);
    --color-orange-a15: rgba(246, 193, 119, 0.15);
    --color-orange-a30: rgba(246, 193, 119, 0.3);
    --color-muted-a15: rgba(110, 106, 134, 0.15);

    --color-status-pending: #6e6a86;
    --color-status-running: #c4a7e7;
    --color-status-complete: #9ccfd8;
    --color-status-error: #eb6f92;

    --color-node-source: #c4a7e7;
    --color-node-features: #9ccfd8;
    --color-node-model: #ebbcba;
    --color-node-ensemble: #9ccfd8;
    --color-node-calibration: #f6c177;
    --color-node-output: #eb6f92;

    --color-tool-models: #ebbcba;
    --color-tool-pipeline: #9ccfd8;
    --color-tool-data: #c4a7e7;
    --color-tool-features: #9ccfd8;
    --color-tool-experiments: #eb6f92;
    --color-tool-config: #f6c177;

    --shadow-sm: 0 1px 2px rgba(0, 0, 0, 0.4);
    --shadow-md: 0 4px 12px rgba(0, 0, 0, 0.4);
    --shadow-lg: 0 4px 12px rgba(0, 0, 0, 0.5);
    --shadow-glow-accent: 0 0 12px var(--color-accent-a25), inset 0 0 0 1px var(--color-accent-a10);
}
