[data-theme="brutalist-light"] {
    --color-bg-primary: #ffffff;
    --color-bg-secondary: #f0f0f0;
    --color-bg-tertiary: #e0e0e0;
    --color-bg-hover: #d0d0d0;
    --color-border: #000000;
    --color-border-subtle: #cccccc;

    --color-text-primary: #000000;
    --color-text-secondary: #444444;
    --color-text-muted: #777777;

    --color-accent: #000000;
    --color-success: #007700;
    --color-warning: #886600;
    --color-error: #cc0000;
    --color-orange: #aa4400;

    --color-accent-a06: rgba(0, 0, 0, 0.06);
    --color-accent-a08: rgba(0, 0, 0, 0.08);
    --color-accent-a10: rgba(0, 0, 0, 0.1);
    --color-accent-a12: rgba(0, 0, 0, 0.12);
    --color-accent-a25: rgba(0, 0, 0, 0.25);
    --color-accent-a30: rgba(0, 0, 0, 0.3);

    --color-success-a15: rgba(0, 119, 0, 0.15);
    --color-success-a30: rgba(0, 119, 0, 0.3);
    --color-warning-a15: rgba(136, 102, 0, 0.15);
    --color-warning-a40: rgba(136, 102, 0, 0.4);
    --color-error-a40: rgba(204, 0, 0, 0.4);
    --color-orange-a15: rgba(170, 68, 0, 0.15);
    --color-orange-a30: rgba(170, 68, 0, 0.3);
    --color-muted-a15: rgba(119, 119, 119, 0.15);

    --color-status-pending: #777777;
    --color-status-running: #000000;
    --color-status-complete: #007700;
    --color-status-error: #cc0000;

    --color-node-source: #444444;
    --color-node-features: #222222;
    --color-node-model: #000000;
    --color-node-ensemble: #007700;
    --color-node-calibration: #886600;
    --color-node-output: #aa4400;

    --color-tool-models: #000000;
    --color-tool-pipeline: #007700;
    --color-tool-data: #444444;
    --color-tool-features: #222222;
    --color-tool-experiments: #aa4400;
    --color-tool-config: #886600;

    --radius-sm: 0px;
    --radius-md: 0px;
    --radius-lg: 0px;

    --shadow-sm: none;
    --shadow-md: none;
    --shadow-lg: none;
    --shadow-glow-accent: inset 0 0 0 2px var(--color-accent);
}
