.box {
    background: var(--color-bg-tertiary);
    border: 1px solid var(--color-border);
    border-radius: var(--radius-md);
    padding: var(--space-3);
    min-width: 120px;
}

.label {
    font-family: var(--font-sans);
    font-size: var(--font-size-xs);
    color: var(--color-text-muted);
    text-transform: uppercase;
    letter-spacing: 0.05em;
}

.value {
    font-family: var(--font-mono);
    font-size: var(--font-size-xl);
    color: var(--color-text-primary);
    font-weight: 600;
}

.success {
    color: var(--color-success);
}

.warning {
    color: var(--color-warning);
}

.error {
    color: var(--color-error);
}

.subtitle {
    font-family: var(--font-mono);
    font-size: var(--font-size-xs);
    color: var(--color-text-secondary);
}
